**_python-docx-oss_** is a Python library for CRUD Microsoft Word (.docx) files.


<p>
    <a href="https://pypi.org/project/python-docx-oss/"><img alt="PyPI" src="https://img.shields.io/pypi/v/python-docx-oss"></a>
    <a href="https://pypi.org/project/python-docx-oss"> <img src="https://img.shields.io/pypi/pyversions/python-docx-oss.svg"/></a>
    <a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
    <a href="https://github.com/lsaint/python-docx-oss/blob/master/LICENSE"><img alt="License: MIT" src="https://img.shields.io/badge/License-MIT-yellow.svg"></a>
</p>

---

### FAQ

**Q: What's New?**

**A:** [HISTORY](https://github.com/lsaint/python-docx-oss/blob/master/HISTORY.md)

---

More information is available in the [python-docx documentation](https://python-docx.readthedocs.org/en/latest/)
